ssbkonf — ssbkonf 0.0.6 documentation

# `ssbkonf`

A Python package for applying output disclosure control to pandas.DataFrames. It is first and foremost a set of wrappers that call the R functions that implement the methods.

The package consists of two main submodules:

- suppress: this module contains functions for applying cell suppression to tables. The current implementation includes a wrapper function for suppressing small counts in frequency tables.

- perturb: this module contains functions for applying perturbative methods to tables. Currently, the only implemented method is small count rounding. Future versions might include cell-key perturbation.

## Submodules

- `ssbkonf.pckg`
- `ssbkonf.perturb`
- `ssbkonf.suppress`
- `ssbkonf.util`

## Package Contents

### Functions

`example_data`(name) |

### Attributes

`__version__` |
`__ssbtools` |

ssbkonf.__version__ = '0.0.6'

ssbkonf.__ssbtools

ssbkonf.example_data(name)